Embed — Map of Objects

Skip to main content
`Ctrl`+`K`

# Embed

embed(experiment_id, embedding_id: str | None = None, num_iterations: int = 1000, radius: float = inf, dim: int = 2, num_neighbors: int | None = None, method: str = 'standard', zero_distance: float = 1.0, factor: float = 1.0, saveas: str | None = None, init_pos: dict | None = None, fixed=True, attraction_factor=None, left=None, up=None, right=None, down=None, **kwargs) → None

  Embeds the distances of an experiment using a given embedding method.